@@ -29,7 +29,9 @@ class FieldsView:
         return f"FieldsView({', '.join(sorted(self._items))})"
 
     def __iter__(self) -> Iterator[str]:
-        return iter(sorted(self._items, key=lambda field: ("." in field, field)))
+        return iter(
+            sorted(self._items, key=lambda field: ("." in field, len(field), field))
+        )
 
     __repr__ = __str__
 
