@@ -18,6 +18,9 @@ class DataTable(GenericModel, Generic[_T]):
     total_results: int
     items: list[_T]
 
+    class Config:
+        arbitrary_types_allowed = True
+
     def __len__(self) -> int:
         return len(self.items)
 
